@@ -153,8 +153,8 @@ parse_options(int* argc, char** argv[])
       "  or will not be wrapped at all if other parameters make it impossible to\n"
       "  layout correctly.\n"
       "\n"
-      "Thank you for using libaosd!\n"
-      "Please send bug reports to: http://bugzilla.atheme.org/");
+      "Thank you for using " PACKAGE_NAME "!\n"
+      "Please send bug reports to: " PACKAGE_BUGREPORT);
 
   /* Fill context option groups */
 #define ADD_GROUP(name, desc) \
@@ -278,10 +278,6 @@ setup(void)
 static void
 clean_queue(void)
 {
-  if (config.age == 0 &&
-      config.lines == 0)
-    return;
-
   if (config.lines != 0)
     while (g_queue_get_length(data.list) > config.lines)
       KILL_FIRST;
