@@ -12,13 +12,10 @@
 
 #include "aosd.h"
 
-#include "pango/pangocairo.h"
-
 typedef struct
 {
   AosdRenderer render_cb;
   void* data;
-  void (*data_destroyer)(void*);
 } RenderCallback;
 
 typedef struct
@@ -30,7 +27,7 @@ typedef struct
 typedef struct
 {
   Pixmap pixmap;
-  int set;
+  Bool set;
 } AosdBackground;
 
 struct _Aosd
@@ -42,21 +39,21 @@ struct _Aosd
   Window win;
   Visual* visual;
   Colormap colormap;
-  PangoLayout* layout;
   int x, y, width, height;
 
   AosdBackground background;
   RenderCallback renderer;
   AosdTransparency mode;
   MouseEventCallback mouse_processor;
+
+  Bool mouse_hide;
+  Bool shown;
 };
 
 void make_window(Aosd*);
 void set_window_properties(Display*, Window);
 Pixmap take_snapshot(Aosd*);
 
-void aosd_destroy_text(Aosd*);
-
 #ifdef HAVE_XCOMPOSITE
 Bool composite_check_ext_and_mgr(Display*, int);
 Visual* composite_find_argb_visual(Display*, int);
